
from setuptools import setup, find_packages


setup(
    name='dummy_132',
    version='0.0.1',
    license='MIT',
    author="uniquename21",
    author_email='uniquename21@yahoo.com',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    keywords='dummy project'
)